<?php
/**
 * Home Construction Company functions and definitions
 *
 * @package Home Construction Company
 */

/**
 * Set the content width based on the theme's design and stylesheet.
 */

/* Theme Setup */
if ( ! function_exists( 'home_construction_company_setup' ) ) :

function home_construction_company_setup() {

	$GLOBALS['content_width'] = apply_filters( 'home_construction_company_content_width', 640 );

	load_theme_textdomain( 'home-construction-company', get_template_directory() . '/languages' );
	add_theme_support( 'automatic-feed-links' );
	add_theme_support( 'post-thumbnails' );
	add_theme_support( 'woocommerce' );
	add_theme_support( 'align-wide' );
	add_theme_support( 'wp-block-styles' );
	add_theme_support( 'title-tag' );
	add_theme_support( 'custom-logo', array(
		'height'      => 240,
		'width'       => 240,
		'flex-height' => true,
	) );
	add_image_size('home-construction-company-homepage-thumb',240,145,true);
	
   	register_nav_menus( array(
		'primary' => __( 'Primary Menu', 'home-construction-company' ),
	) );

	add_theme_support( 'custom-background', array(
		'default-color' => 'f1f1f1'
	) );
	
	add_theme_support ('html5', array (
        'search-form', 'comment-form', 'comment-list', 'gallery', 'caption'
    ) );

	add_theme_support('responsive-embeds');

	/* Selective refresh for widgets */
	add_theme_support( 'customize-selective-refresh-widgets' );

	/*
	 * This theme styles the visual editor to resemble the theme style,
	 * specifically font, colors, icons, and column width.
	 */
	add_editor_style( array( 'css/editor-style.css', home_construction_company_font_url() ) );
}
endif;
add_action( 'after_setup_theme', 'home_construction_company_setup' );

/* Theme Widgets Setup */
function home_construction_company_widgets_init() {
	register_sidebar( array(
		'name'          => __( 'Blog Sidebar', 'home-construction-company' ),
		'description'   => __( 'Appears on blog page sidebar', 'home-construction-company' ),
		'id'            => 'sidebar-1',
		'before_widget' => '<aside id="%1$s" class="widget %2$s p-2">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );
	
	register_sidebar( array(
		'name'          => __( 'Page Sidebar', 'home-construction-company' ),
		'description'   => __( 'Appears on page sidebar', 'home-construction-company' ),
		'id'            => 'sidebar-2',
		'before_widget' => '<aside id="%1$s" class="widget %2$s p-2">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'         => __( 'Third Column Sidebar', 'home-construction-company' ),
		'description' => __( 'Appears on page sidebar', 'home-construction-company' ),
		'id'            => 'sidebar-3',
		'before_widget' => '<aside id="%1$s" class="widget %2$s p-2">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	//Footer widget areas
	$home_construction_company_widget_areas = get_theme_mod('home_construction_company_footer_widget_layout', '4');
	for ($i=1; $i<=$home_construction_company_widget_areas; $i++) {
		register_sidebar( array(
			'name'        => __( 'Footer Nav ', 'home-construction-company' ) . $i,
			'id'          => 'footer-' . $i,
			'description' => '',
			'before_widget' => '<aside id="%1$s" class="widget %2$s py-2">',
			'after_widget'  => '</aside>',
			'before_title'  => '<h3 class="widget-title">',
			'after_title'   => '</h3>',
		) );
	}
	register_sidebar( array(
		'name'          => __( 'Shop Page Sidebar', 'home-construction-company' ),
		'description'   => __( 'Appears on shop page', 'home-construction-company' ),	
		'id'            => 'woocommerce_sidebar',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );
	register_sidebar( array(
		'name'          => __( 'Single Product Page Sidebar', 'home-construction-company' ),
		'description'   => __( 'Appears on shop page', 'home-construction-company' ),
		'id'            => 'woocommerce-single-sidebar',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );
}
add_action( 'widgets_init', 'home_construction_company_widgets_init' );

/* Theme Font URL */
function home_construction_company_font_url() {
	$font_family = array(
	    'ABeeZee:ital@0;1',
		'Abril Fatfac',
		'Acme',
		'Anton',
		'Architects Daughter',
		'Arimo:ital,wght@0,400;0,500;0,600;0,700;1,400;1,500;1,600;1,700',
		'Arsenal:ital,wght@0,400;0,700;1,400;1,700',
		'Arvo:ital,wght@0,400;0,700;1,400;1,700',
		'Alegreya:ital,wght@0,400;0,500;0,600;0,700;0,800;0,900;1,400;1,500;1,600;1,700;1,800;1,900',
		'Alfa Slab One',
		'Averia Serif Libre:ital,wght@0,300;0,400;0,700;1,300;1,400;1,700',
		'Bangers',
		'Boogaloo',
		'Bad Script',
		'Bitter:ital,wght@0,100;0,200;0,300;0,400;0,500;0,600;0,700;0,800;0,900;1,100;1,200;1,300;1,400;1,500;1,600;1,700;1,800;1,900',
		'Bree Serif',
		'BenchNine:wght@300;400;700',
		'Cabin:ital,wght@0,400;0,500;0,600;0,700;1,400;1,500;1,600;1,700',
		'Cardo:ital,wght@0,400;0,700;1,400',
		'Courgette',
		'Cherry Swash:wght@400;700',
		'Cormorant Garamond:ital,wght@0,300;0,400;0,500;0,600;0,700;1,300;1,400;1,500;1,600;1,700',
		'Crimson Text:ital,wght@0,400;0,600;0,700;1,400;1,600;1,700',
		'Cuprum:ital,wght@0,400;0,500;0,600;0,700;1,400;1,500;1,600;1,700',
		'Cookie',
		'Coming Soon',
		'Chewy',
		'Days One',
		'Dosis:wght@200;300;400;500;600;700;800',
		'Economica:ital,wght@0,400;0,700;1,400;1,700',
		'Fira Sans:ital,wght@0,100;0,200;0,300;0,400;0,500;0,600;0,700;0,800;0,900;1,100;1,200;1,300;1,400;1,500;1,600;1,700;1,800;1,900',
		'Fredoka One',
		'Fjalla One',
		'Francois One',
		'Frank Ruhl Libre:wght@300;400;500;700;900',
		'Gloria Hallelujah',
		'Great Vibes',
		'Handlee',
		'Hammersmith One',
		'Heebo:wght@100;200;300;400;500;600;700;800;900',
		'Inconsolata:wght@200;300;400;500;600;700;800;900',
		'Indie Flower',
		'IM Fell English SC',
		'Julius Sans One',
		'Josefin Slab:ital,wght@0,100;0,200;0,300;0,400;0,500;0,600;0,700;1,100;1,200;1,300;1,400;1,500;1,600;1,700',
		'Josefin Sans:ital,wght@0,100;0,200;0,300;0,400;0,500;0,600;0,700;1,100;1,200;1,300;1,400;1,500;1,600;1,700',
		'Jost:ital,wght@0,100;0,200;0,300;0,400;0,500;0,600;0,700;0,800;0,900;1,100;1,200;1,300;1,400;1,500;1,600;1,700;1,800;1,900',
		'Kanit:ital,wght@0,100;0,200;0,300;0,400;0,500;0,600;0,700;0,800;0,900;1,100;1,200;1,300;1,400;1,500;1,600;1,700;1,800;1,900',
		'Lobster',
		'Lato:ital,wght@0,100;0,300;0,400;0,700;0,900;1,100;1,300;1,400;1,700;1,900',
		'Lora:ital,wght@0,400;0,500;0,600;0,700;1,400;1,500;1,600;1,700',
		'Libre Baskerville:ital,wght@0,400;0,700;1,400',
		'Lobster Two:ital,wght@0,400;0,700;1,400;1,700',
		'Merriweather:ital,wght@0,300;0,400;0,700;0,900;1,300;1,400;1,700;1,900',
		'Monda:wght@400;700',
		'Montserrat:ital,wght@0,100;0,200;0,300;0,400;0,500;0,600;0,700;0,800;0,900;1,100;1,200;1,300;1,400;1,500;1,600;1,700;1,800;1,900',
		'Mulish:ital,wght@0,200;0,300;0,400;0,500;0,600;0,700;0,800;0,900;1,200;1,300;1,400;1,500;1,600;1,700;1,800;1,900',
		'Marck Script',
		'Noto Serif:ital,wght@0,400;0,700;1,400;1,700',
		'Open Sans:ital,wght@0,300;0,400;0,500;0,600;0,700;0,800;1,300;1,400;1,500;1,600;1,700;1,800',
		'Overpass:ital,wght@0,100;0,200;0,300;0,400;0,500;0,600;0,700;0,800;0,900;1,100;1,200;1,300;1,400;1,500;1,600;1,700;1,800;1,900',
		'Overpass Mono:wght@300;400;500;600;700',
		'Oxygen:wght@300;400;700',
		'Orbitron:wght@400;500;600;700;800;900',
		'Patua One',
		'Pacifico',
		'Padauk:wght@400;700',
		'Playball',
		'Playfair Display:ital,wght@0,400;0,500;0,600;0,700;0,800;0,900;1,400;1,500;1,600;1,700;1,800;1,900',
		'PT Sans:ital,wght@0,400;0,700;1,400;1,700',
		'Philosopher:ital,wght@0,400;0,700;1,400;1,700',
		'Permanent Marker',
		'Poiret One',
		'Poppins:ital,wght@0,100;0,200;0,300;0,400;0,500;0,600;0,700;0,800;0,900;1,100;1,200;1,300;1,400;1,500;1,600;1,700;1,800;1,900',
		'Quicksand:wght@300;400;500;600;700',
		'Quattrocento Sans:ital,wght@0,400;0,700;1,400;1,700',
		'Raleway:ital,wght@0,100;0,200;0,300;0,400;0,500;0,600;0,700;0,800;0,900;1,100;1,200;1,300;1,400;1,500;1,600;1,700;1,800;1,900',
		'Rubik:ital,wght@0,300;0,400;0,500;0,600;0,700;0,800;0,900;1,300;1,400;1,500;1,600;1,700;1,800;1,900',
		'Roboto Condensed:ital,wght@0,300;0,400;0,700;1,300;1,400;1,700',
		'Rokkitt:wght@100;200;300;400;500;600;700;800;900',
		'Russo One',
		'Righteous',
		'Saira:ital,wght@0,100;0,200;0,300;0,400;0,500;0,600;0,700;0,800;0,900;1,100;1,200;1,300;1,400;1,500;1,600;1,700;1,800;1,900',
		'Satisfy',
		'Slabo 13px',
		'Slabo 27px',
		'Source Sans Pro:ital,wght@0,200;0,300;0,400;0,600;0,700;0,900;1,200;1,300;1,400;1,600;1,700;1,900',
		'Shadows Into Light Two',
		'Shadows Into Light',
		'Sacramento',
		'Shrikhand',
		'Staatliches',
		'Tangerine:wght@400;700',
		'Trirong:ital,wght@0,100;0,200;0,300;0,400;0,500;0,600;0,700;0,800;0,900;1,100;1,200;1,300;1,400;1,500;1,600;1,700;1,800;1,900',
		'Ubuntu:ital,wght@0,300;0,400;0,500;0,700;1,300;1,400;1,500;1,700',
		'Unica One',
		'VT323',
		'Varela Round',
		'Vampiro One',
		'Vollkorn:ital,wght@0,400;0,500;0,600;0,700;0,800;0,900;1,400;1,500;1,600;1,700;1,800;1,900',
		'Volkhov:ital,wght@0,400;0,700;1,400;1,700',
		'Work Sans:ital,wght@0,100;0,200;0,300;0,400;0,500;0,600;0,700;0,800;0,900;1,100;1,200;1,300;1,400;1,500;1,600;1,700;1,800;1,900',
		'Yanone Kaffeesatz:wght@200;300;400;500;600;700',
		'ZCOOL XiaoWei'
	);
	
	$fonts_url = add_query_arg( array(
		'family' => implode( '&family=', $font_family ),
		'display' => 'swap',
	), 'https://fonts.googleapis.com/css2' );

	$contents = wptt_get_webfont_url( esc_url_raw( $fonts_url ) );
	return $contents;
}

/* Theme enqueue scripts */
function home_construction_company_scripts() {
	wp_enqueue_style( 'home-construction-company-font', home_construction_company_font_url(), array() );
	wp_enqueue_style( 'home-construction-company-block-patterns-style-frontend', get_theme_file_uri('/css/block-frontend.css') );
	wp_enqueue_style( 'bootstrap-css', get_template_directory_uri().'/css/bootstrap.css' );
	wp_enqueue_style( 'home-construction-company-basic-style', get_stylesheet_uri() );
	wp_enqueue_style( 'font-awesome-css', get_template_directory_uri().'/css/fontawesome-all.css' );
	wp_enqueue_style( 'home-construction-company-block-style', get_template_directory_uri().'/css/block-style.css' );

    // Body
    $home_construction_company_body_color = get_theme_mod('home_construction_company_body_color', '');
    $home_construction_company_body_font_family = get_theme_mod('home_construction_company_body_font_family', '');
    $home_construction_company_body_font_size = get_theme_mod('home_construction_company_body_font_size', '');
	// Paragraph
    $home_construction_company_paragraph_color = get_theme_mod('home_construction_company_paragraph_color', '');
    $home_construction_company_paragraph_font_family = get_theme_mod('home_construction_company_paragraph_font_family', '');
    $home_construction_company_paragraph_font_size = get_theme_mod('home_construction_company_paragraph_font_size', '');
	// "a" tag
	$home_construction_company_atag_color = get_theme_mod('home_construction_company_atag_color', '');
    $home_construction_company_atag_font_family = get_theme_mod('home_construction_company_atag_font_family', '');
	// "li" tag
	$home_construction_company_li_color = get_theme_mod('home_construction_company_li_color', '');
    $home_construction_company_li_font_family = get_theme_mod('home_construction_company_li_font_family', '');
	// H1
	$home_construction_company_h1_color = get_theme_mod('home_construction_company_h1_color', '');
    $home_construction_company_h1_font_family = get_theme_mod('home_construction_company_h1_font_family', '');
    $home_construction_company_h1_font_size = get_theme_mod('home_construction_company_h1_font_size', '');
	// H2
	$home_construction_company_h2_color = get_theme_mod('home_construction_company_h2_color', '');
    $home_construction_company_h2_font_family = get_theme_mod('home_construction_company_h2_font_family', '');
    $home_construction_company_h2_font_size = get_theme_mod('home_construction_company_h2_font_size', '');
	// H3
	$home_construction_company_h3_color = get_theme_mod('home_construction_company_h3_color', '');
    $home_construction_company_h3_font_family = get_theme_mod('home_construction_company_h3_font_family', '');
    $home_construction_company_h3_font_size = get_theme_mod('home_construction_company_h3_font_size', '');
	// H4
	$home_construction_company_h4_color = get_theme_mod('home_construction_company_h4_color', '');
    $home_construction_company_h4_font_family = get_theme_mod('home_construction_company_h4_font_family', '');
    $home_construction_company_h4_font_size = get_theme_mod('home_construction_company_h4_font_size', '');
	// H5
	$home_construction_company_h5_color = get_theme_mod('home_construction_company_h5_color', '');
    $home_construction_company_h5_font_family = get_theme_mod('home_construction_company_h5_font_family', '');
    $home_construction_company_h5_font_size = get_theme_mod('home_construction_company_h5_font_size', '');
	// H6
	$home_construction_company_h6_color = get_theme_mod('home_construction_company_h6_color', '');
    $home_construction_company_h6_font_family = get_theme_mod('home_construction_company_h6_font_family', '');
    $home_construction_company_h6_font_size = get_theme_mod('home_construction_company_h6_font_size', '');

	$home_construction_company_custom_css ='
	    body{
		    color:'.esc_attr($home_construction_company_body_color).'!important;
		    font-family: '.esc_attr($home_construction_company_body_font_family).'!important;
		    font-size: '.esc_attr($home_construction_company_body_font_size).'px !important;
		}
		p,span{
		    color:'.esc_attr($home_construction_company_paragraph_color).'!important;
		    font-family: '.esc_attr($home_construction_company_paragraph_font_family).'!important;
		    font-size: '.esc_attr($home_construction_company_paragraph_font_size).'!important;
		}
		a{
		    color:'.esc_attr($home_construction_company_atag_color).'!important;
		    font-family: '.esc_attr($home_construction_company_atag_font_family).';
		}
		li{
		    color:'.esc_attr($home_construction_company_li_color).'!important;
		    font-family: '.esc_attr($home_construction_company_li_font_family).';
		}
		h1{
		    color:'.esc_attr($home_construction_company_h1_color).'!important;
		    font-family: '.esc_attr($home_construction_company_h1_font_family).'!important;
		    font-size: '.esc_attr($home_construction_company_h1_font_size).'!important;
		}
		h2{
		    color:'.esc_attr($home_construction_company_h2_color).'!important;
		    font-family: '.esc_attr($home_construction_company_h2_font_family).'!important;
		    font-size: '.esc_attr($home_construction_company_h2_font_size).'!important;
		}
		h3{
		    color:'.esc_attr($home_construction_company_h3_color).'!important;
		    font-family: '.esc_attr($home_construction_company_h3_font_family).'!important;
		    font-size: '.esc_attr($home_construction_company_h3_font_size).'!important;
		}
		h4{
		    color:'.esc_attr($home_construction_company_h4_color).'!important;
		    font-family: '.esc_attr($home_construction_company_h4_font_family).'!important;
		    font-size: '.esc_attr($home_construction_company_h4_font_size).'!important;
		}
		h5{
		    color:'.esc_attr($home_construction_company_h5_color).'!important;
		    font-family: '.esc_attr($home_construction_company_h5_font_family).'!important;
		    font-size: '.esc_attr($home_construction_company_h5_font_size).'!important;
		}
		h6{
		    color:'.esc_attr($home_construction_company_h6_color).'!important;
		    font-family: '.esc_attr($home_construction_company_h6_font_family).'!important;
		    font-size: '.esc_attr($home_construction_company_h6_font_size).'!important;
		}'
	;
	wp_add_inline_style( 'home-construction-company-basic-style',$home_construction_company_custom_css );

	require get_parent_theme_file_path( '/tc-style.php' );
	wp_add_inline_style( 'home-construction-company-basic-style',$home_construction_company_custom_css );

	wp_enqueue_script( 'bootstrap-js', get_template_directory_uri() . '/js/bootstrap.js' );
	wp_enqueue_script( 'home-construction-company-custom-jquery', get_template_directory_uri() . '/js/custom.js', array('jquery') );
	wp_enqueue_script( 'jquery-superfish', get_template_directory_uri() . '/js/jquery.superfish.js', array('jquery') ,'',true);
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'home_construction_company_scripts' );

/*radio button sanitization*/
function home_construction_company_sanitize_choices( $input, $setting ) {
    global $wp_customize; 
    $control = $wp_customize->get_control( $setting->id ); 
    if ( array_key_exists( $input, $control->choices ) ) {
        return $input;
    } else {
        return $setting->default;
    }
}

/* Excerpt Limit Begin */
function home_construction_company_string_limit_words($string, $word_limit) {
	$words = explode(' ', $string, ($word_limit + 1));
	if(count($words) > $word_limit)
	array_pop($words);
	return implode(' ', $words);
}

function home_construction_company_sanitize_phone_number( $phone ) {
	return preg_replace( '/[^\d+]/', '', $phone );
}

function home_construction_company_sanitize_dropdown_pages( $page_id, $setting ) {
  	// Ensure $input is an absolute integer.
  	$page_id = absint( $page_id );

  	// If $page_id is an ID of a published page, return it; otherwise, return the default.
  	return ( 'publish' == get_post_status( $page_id ) ? $page_id : $setting->default );
}

// Change number or products per row to 3
add_filter('loop_shop_columns', 'home_construction_company_loop_columns');
if (!function_exists('home_construction_company_loop_columns')) {
	function home_construction_company_loop_columns() {
		$columns = get_theme_mod( 'home_construction_company_products_per_row', 3 );
		return $columns; // 3 products per row
	}
}

//Change number of products that are displayed per page (shop page)
add_filter( 'loop_shop_per_page', 'home_construction_company_shop_per_page', 9 );
function home_construction_company_shop_per_page( $cols ) {
  	$cols = get_theme_mod( 'home_construction_company_product_per_page', 9 );
	return $cols;
}

function home_construction_company_sanitize_checkbox( $input ) {
	// Boolean check 
	return ( ( isset( $input ) && true == $input ) ? true : false );
}

function home_construction_company_sanitize_float( $input ) {
    return filter_var($input, FILTER_SANITIZE_NUMBER_FLOAT, FILTER_FLAG_ALLOW_FRACTION);
}

/** Posts navigation. */
if ( ! function_exists( 'home_construction_company_post_navigation' ) ) {
	function home_construction_company_post_navigation() {
		$home_construction_company_pagination_type = get_theme_mod( 'home_construction_company_post_navigation_type', 'numbers' );
		if ( $home_construction_company_pagination_type == 'numbers' ) {
			the_posts_pagination();
		} else {
			the_posts_navigation( array(
	            'prev_text'          => __( 'Previous page', 'home-construction-company' ),
	            'next_text'          => __( 'Next page', 'home-construction-company' ),
	            'before_page_number' => '<span class="meta-nav screen-reader-text">' . __( 'Page', 'home-construction-company' ) . ' </span>',
	        ) );
		}
	}
}

/* Custom template tags for this theme. */
require get_template_directory() . '/inc/template-tags.php';

/* Implement the Custom Header feature. */
require get_template_directory() . '/inc/custom-header.php';

/* Customizer additions. */
require get_template_directory() . '/inc/customizer.php';

/* Webfonts */
require get_template_directory() . '/wptt-webfont-loader.php';

