<?php
/**
 * Home Construction Company Theme Customizer
 *
 * @package Home Construction Company
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function home_construction_company_customize_register( $wp_customize ) {

	load_template( trailingslashit( get_template_directory() ) . '/inc/icon-changer.php' );

	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';

	$wp_customize->selective_refresh->add_partial(
		'blogname',
		array(
			'selector'        => '.site-title a',
			'render_callback' => 'home_construction_company_customize_partial_blogname',
		)
	);
	$wp_customize->selective_refresh->add_partial(
		'blogdescription',
		array(
			'selector'        => '.site-description',
			'render_callback' => 'home_construction_company_customize_partial_blogdescription',
		)
	);

	//add home page setting pannel
	$wp_customize->add_panel( 'home_construction_company_panel_id', array(
	    'priority' => 10,
	    'capability' => 'edit_theme_options',
	    'theme_supports' => '',
	    'title' => __( 'Theme Settings', 'home-construction-company' ),
	) );

    $home_construction_company_font_array= array(
        '' =>'No Fonts',
        'Abril Fatface' => 'Abril Fatface',
        'Acme' =>'Acme', 
        'Anton' => 'Anton', 
        'Architects Daughter' =>'Architects Daughter',
        'Arimo' => 'Arimo', 
        'Arsenal' =>'Arsenal',
        'Arvo' =>'Arvo',
        'Alegreya' =>'Alegreya',
        'Alfa Slab One' =>'Alfa Slab One',
        'Averia Serif Libre' =>'Averia Serif Libre', 
        'Bangers' =>'Bangers', 
        'Boogaloo' =>'Boogaloo', 
        'Bad Script' =>'Bad Script',
        'Bitter' =>'Bitter', 
        'Bree Serif' =>'Bree Serif', 
        'BenchNine' =>'BenchNine',
        'Cabin' =>'Cabin',
        'Cardo' =>'Cardo', 
        'Courgette' =>'Courgette', 
        'Cherry Swash' =>'Cherry Swash',
        'Cormorant Garamond' =>'Cormorant Garamond', 
        'Crimson Text' =>'Crimson Text',
        'Cuprum' =>'Cuprum', 
        'Cookie' =>'Cookie',
        'Chewy' =>'Chewy',
        'Days One' =>'Days One',
        'Dosis' =>'Dosis',
        'Droid Sans' =>'Droid Sans', 
        'Economica' =>'Economica', 
        'Fredoka One' =>'Fredoka One',
        'Fjalla One' =>'Fjalla One',
        'Francois One' =>'Francois One', 
        'Frank Ruhl Libre' => 'Frank Ruhl Libre', 
        'Gloria Hallelujah' =>'Gloria Hallelujah',
        'Great Vibes' =>'Great Vibes', 
        'Handlee' =>'Handlee', 
        'Hammersmith One' =>'Hammersmith One',
        'Inconsolata' =>'Inconsolata',
        'Indie Flower' =>'Indie Flower', 
        'IM Fell English SC' =>'IM Fell English SC',
        'Julius Sans One' =>'Julius Sans One',
        'Josefin Slab' =>'Josefin Slab',
        'Josefin Sans' =>'Josefin Sans',
        'Kanit' =>'Kanit',
        'Lobster' =>'Lobster',
        'Lato' => 'Lato',
        'Lora' =>'Lora', 
        'Libre Baskerville' =>'Libre Baskerville',
        'Lobster Two' => 'Lobster Two',
        'Merriweather' =>'Merriweather',
        'Monda' =>'Monda',
        'Montserrat' =>'Montserrat',
        'Muli' =>'Muli',
        'Marck Script' =>'Marck Script',
        'Noto Serif' =>'Noto Serif',
        'Open Sans' =>'Open Sans',
        'Overpass' => 'Overpass', 
        'Overpass Mono' =>'Overpass Mono',
        'Oxygen' =>'Oxygen',
        'Orbitron' =>'Orbitron',
        'Patua One' =>'Patua One',
        'Pacifico' =>'Pacifico',
        'Padauk' =>'Padauk',
        'Playball' =>'Playball',
        'Playfair Display' =>'Playfair Display',
        'PT Sans' =>'PT Sans',
        'Philosopher' =>'Philosopher',
        'Permanent Marker' =>'Permanent Marker',
        'Poiret One' =>'Poiret One',
        'Quicksand' =>'Quicksand',
        'Quattrocento Sans' =>'Quattrocento Sans',
        'Raleway' =>'Raleway',
        'Rubik' =>'Rubik',
        'Rokkitt' =>'Rokkitt',
        'Russo One' => 'Russo One', 
        'Righteous' =>'Righteous', 
        'Slabo' =>'Slabo', 
        'Source Sans Pro' =>'Source Sans Pro',
        'Shadows Into Light Two' =>'Shadows Into Light Two',
        'Shadows Into Light' =>  'Shadows Into Light',
        'Sacramento' =>'Sacramento',
        'Shrikhand' =>'Shrikhand',
        'Tangerine' => 'Tangerine',
        'Ubuntu' =>'Ubuntu',
        'VT323' =>'VT323',
        'Varela Round' =>'Varela Round',
        'Vampiro One' =>'Vampiro One',
        'Vollkorn' => 'Vollkorn',
        'Volkhov' =>'Volkhov',
        'Kavoon' =>'Kavoon',
        'Yanone Kaffeesatz' =>'Yanone Kaffeesatz'
    );

	//Color / Font Pallete
	$wp_customize->add_section( 'home_construction_company_typography', array(
    	'title'      => __( 'Color / Font Pallete', 'home-construction-company' ),
		'priority'   => 30,
		'panel' => 'home_construction_company_panel_id'
	) );

	// This is Body Color setting
	$wp_customize->add_setting( 'home_construction_company_body_color', array(
		'default' => '',
		'sanitize_callback'	=> 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'home_construction_company_body_color', array(
		'label' => __('Body Color', 'home-construction-company'),
		'section' => 'home_construction_company_typography',
		'settings' => 'home_construction_company_body_color',
	)));

	//This is Body FontFamily  setting
	$wp_customize->add_setting('home_construction_company_body_font_family',array(
	  'default' => '',
	  'capability' => 'edit_theme_options',
	  'sanitize_callback' => 'home_construction_company_sanitize_choices'
	));
	$wp_customize->add_control(
		'home_construction_company_body_font_family', array(
		'section'  => 'home_construction_company_typography',
		'label'    => __( 'Body Fonts','home-construction-company'),
		'type'     => 'select',
		'choices'  => $home_construction_company_font_array,
	));

    //This is Body Fontsize setting
	$wp_customize->add_setting('home_construction_company_body_font_size',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('home_construction_company_body_font_size',array(
		'label'	=> __('Body Font Size','home-construction-company'),
		'section'	=> 'home_construction_company_typography',
		'setting'	=> 'home_construction_company_body_font_size',
		'type'	=> 'text'
	));
	
	// This is Paragraph Color picker setting
	$wp_customize->add_setting( 'home_construction_company_paragraph_color', array(
		'default' => '',
		'sanitize_callback'	=> 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'home_construction_company_paragraph_color', array(
		'label' => __('Paragraph Color', 'home-construction-company'),
		'section' => 'home_construction_company_typography',
		'settings' => 'home_construction_company_paragraph_color',
	)));

	//This is Paragraph FontFamily picker setting
	$wp_customize->add_setting('home_construction_company_paragraph_font_family',array(
	  'default' => '',
	  'capability' => 'edit_theme_options',
	  'sanitize_callback' => 'home_construction_company_sanitize_choices'
	));
	$wp_customize->add_control(
	    'home_construction_company_paragraph_font_family', array(
	    'section'  => 'home_construction_company_typography',
	    'label'    => __( 'Paragraph Fonts','home-construction-company'),
	    'type'     => 'select',
	    'choices'  => $home_construction_company_font_array,
	));

	$wp_customize->add_setting('home_construction_company_paragraph_font_size',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('home_construction_company_paragraph_font_size',array(
		'label'	=> __('Paragraph Font Size','home-construction-company'),
		'section'	=> 'home_construction_company_typography',
		'setting'	=> 'home_construction_company_paragraph_font_size',
		'type'	=> 'text'
	));

	// This is "a" Tag Color picker setting
	$wp_customize->add_setting( 'home_construction_company_atag_color', array(
		'default' => '',
		'sanitize_callback'	=> 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'home_construction_company_atag_color', array(
		'label' => __('"a" Tag Color', 'home-construction-company'),
		'section' => 'home_construction_company_typography',
		'settings' => 'home_construction_company_atag_color',
	)));

	//This is "a" Tag FontFamily picker setting
	$wp_customize->add_setting('home_construction_company_atag_font_family',array(
	  'default' => '',
	  'capability' => 'edit_theme_options',
	  'sanitize_callback' => 'home_construction_company_sanitize_choices'
	));
	$wp_customize->add_control(
	    'home_construction_company_atag_font_family', array(
	    'section'  => 'home_construction_company_typography',
	    'label'    => __( '"a" Tag Fonts','home-construction-company'),
	    'type'     => 'select',
	    'choices'  => $home_construction_company_font_array,
	));

	// This is "a" Tag Color picker setting
	$wp_customize->add_setting( 'home_construction_company_li_color', array(
		'default' => '',
		'sanitize_callback'	=> 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'home_construction_company_li_color', array(
		'label' => __('"li" Tag Color', 'home-construction-company'),
		'section' => 'home_construction_company_typography',
		'settings' => 'home_construction_company_li_color',
	)));

	//This is "li" Tag FontFamily picker setting
	$wp_customize->add_setting('home_construction_company_li_font_family',array(
	  'default' => '',
	  'capability' => 'edit_theme_options',
	  'sanitize_callback' => 'home_construction_company_sanitize_choices'
	));
	$wp_customize->add_control(
	    'home_construction_company_li_font_family', array(
	    'section'  => 'home_construction_company_typography',
	    'label'    => __( '"li" Tag Fonts','home-construction-company'),
	    'type'     => 'select',
	    'choices'  => $home_construction_company_font_array,
	));

	// This is H1 Color picker setting
	$wp_customize->add_setting( 'home_construction_company_h1_color', array(
		'default' => '',
		'sanitize_callback'	=> 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'home_construction_company_h1_color', array(
		'label' => __('h1 Color', 'home-construction-company'),
		'section' => 'home_construction_company_typography',
		'settings' => 'home_construction_company_h1_color',
	)));

	//This is H1 FontFamily picker setting
	$wp_customize->add_setting('home_construction_company_h1_font_family',array(
	  'default' => '',
	  'capability' => 'edit_theme_options',
	  'sanitize_callback' => 'home_construction_company_sanitize_choices'
	));
	$wp_customize->add_control(
	    'home_construction_company_h1_font_family', array(
	    'section'  => 'home_construction_company_typography',
	    'label'    => __( 'h1 Fonts','home-construction-company'),
	    'type'     => 'select',
	    'choices'  => $home_construction_company_font_array,
	));

	//This is H1 FontSize setting
	$wp_customize->add_setting('home_construction_company_h1_font_size',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('home_construction_company_h1_font_size',array(
		'label'	=> __('h1 Font Size','home-construction-company'),
		'section'	=> 'home_construction_company_typography',
		'setting'	=> 'home_construction_company_h1_font_size',
		'type'	=> 'text'
	));

	// This is H2 Color picker setting
	$wp_customize->add_setting( 'home_construction_company_h2_color', array(
		'default' => '',
		'sanitize_callback'	=> 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'home_construction_company_h2_color', array(
		'label' => __('h2 Color', 'home-construction-company'),
		'section' => 'home_construction_company_typography',
		'settings' => 'home_construction_company_h2_color',
	)));

	//This is H2 FontFamily picker setting
	$wp_customize->add_setting('home_construction_company_h2_font_family',array(
	  'default' => '',
	  'capability' => 'edit_theme_options',
	  'sanitize_callback' => 'home_construction_company_sanitize_choices'
	));
	$wp_customize->add_control(
	    'home_construction_company_h2_font_family', array(
	    'section'  => 'home_construction_company_typography',
	    'label'    => __( 'h2 Fonts','home-construction-company'),
	    'type'     => 'select',
	    'choices'  => $home_construction_company_font_array,
	));

	//This is H2 FontSize setting
	$wp_customize->add_setting('home_construction_company_h2_font_size',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('home_construction_company_h2_font_size',array(
		'label'	=> __('h2 Font Size','home-construction-company'),
		'section'	=> 'home_construction_company_typography',
		'setting'	=> 'home_construction_company_h2_font_size',
		'type'	=> 'text'
	));

	// This is H3 Color picker setting
	$wp_customize->add_setting( 'home_construction_company_h3_color', array(
		'default' => '',
		'sanitize_callback'	=> 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'home_construction_company_h3_color', array(
		'label' => __('h3 Color', 'home-construction-company'),
		'section' => 'home_construction_company_typography',
		'settings' => 'home_construction_company_h3_color',
	)));

	//This is H3 FontFamily picker setting
	$wp_customize->add_setting('home_construction_company_h3_font_family',array(
	  'default' => '',
	  'capability' => 'edit_theme_options',
	  'sanitize_callback' => 'home_construction_company_sanitize_choices'
	));
	$wp_customize->add_control(
	    'home_construction_company_h3_font_family', array(
	    'section'  => 'home_construction_company_typography',
	    'label'    => __( 'h3 Fonts','home-construction-company'),
	    'type'     => 'select',
	    'choices'  => $home_construction_company_font_array,
	));

	//This is H3 FontSize setting
	$wp_customize->add_setting('home_construction_company_h3_font_size',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('home_construction_company_h3_font_size',array(
		'label'	=> __('h3 Font Size','home-construction-company'),
		'section'	=> 'home_construction_company_typography',
		'setting'	=> 'home_construction_company_h3_font_size',
		'type'	=> 'text'
	));

	// This is H4 Color picker setting
	$wp_customize->add_setting( 'home_construction_company_h4_color', array(
		'default' => '',
		'sanitize_callback'	=> 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'home_construction_company_h4_color', array(
		'label' => __('h4 Color', 'home-construction-company'),
		'section' => 'home_construction_company_typography',
		'settings' => 'home_construction_company_h4_color',
	)));

	//This is H4 FontFamily picker setting
	$wp_customize->add_setting('home_construction_company_h4_font_family',array(
	  'default' => '',
	  'capability' => 'edit_theme_options',
	  'sanitize_callback' => 'home_construction_company_sanitize_choices'
	));
	$wp_customize->add_control(
	    'home_construction_company_h4_font_family', array(
	    'section'  => 'home_construction_company_typography',
	    'label'    => __( 'h4 Fonts','home-construction-company'),
	    'type'     => 'select',
	    'choices'  => $home_construction_company_font_array,
	));

	//This is H4 FontSize setting
	$wp_customize->add_setting('home_construction_company_h4_font_size',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('home_construction_company_h4_font_size',array(
		'label'	=> __('h4 Font Size','home-construction-company'),
		'section'	=> 'home_construction_company_typography',
		'setting'	=> 'home_construction_company_h4_font_size',
		'type'	=> 'text'
	));

	// This is H5 Color picker setting
	$wp_customize->add_setting( 'home_construction_company_h5_color', array(
		'default' => '',
		'sanitize_callback'	=> 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'home_construction_company_h5_color', array(
		'label' => __('h5 Color', 'home-construction-company'),
		'section' => 'home_construction_company_typography',
		'settings' => 'home_construction_company_h5_color',
	)));

	//This is H5 FontFamily picker setting
	$wp_customize->add_setting('home_construction_company_h5_font_family',array(
	  'default' => '',
	  'capability' => 'edit_theme_options',
	  'sanitize_callback' => 'home_construction_company_sanitize_choices'
	));
	$wp_customize->add_control(
	    'home_construction_company_h5_font_family', array(
	    'section'  => 'home_construction_company_typography',
	    'label'    => __( 'h5 Fonts','home-construction-company'),
	    'type'     => 'select',
	    'choices'  => $home_construction_company_font_array,
	));

	//This is H5 FontSize setting
	$wp_customize->add_setting('home_construction_company_h5_font_size',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('home_construction_company_h5_font_size',array(
		'label'	=> __('h5 Font Size','home-construction-company'),
		'section'	=> 'home_construction_company_typography',
		'setting'	=> 'home_construction_company_h5_font_size',
		'type'	=> 'text'
	));

	// This is H6 Color picker setting
	$wp_customize->add_setting( 'home_construction_company_h6_color', array(
		'default' => '',
		'sanitize_callback'	=> 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'home_construction_company_h6_color', array(
		'label' => __('h6 Color', 'home-construction-company'),
		'section' => 'home_construction_company_typography',
		'settings' => 'home_construction_company_h6_color',
	)));

	//This is H6 FontFamily picker setting
	$wp_customize->add_setting('home_construction_company_h6_font_family',array(
	  'default' => '',
	  'capability' => 'edit_theme_options',
	  'sanitize_callback' => 'home_construction_company_sanitize_choices'
	));
	$wp_customize->add_control(
	    'home_construction_company_h6_font_family', array(
	    'section'  => 'home_construction_company_typography',
	    'label'    => __( 'h6 Fonts','home-construction-company'),
	    'type'     => 'select',
	    'choices'  => $home_construction_company_font_array,
	));

	//This is H6 FontSize setting
	$wp_customize->add_setting('home_construction_company_h6_font_size',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('home_construction_company_h6_font_size',array(
		'label'	=> __('h6 Font Size','home-construction-company'),
		'section'	=> 'home_construction_company_typography',
		'setting'	=> 'home_construction_company_h6_font_size',
		'type'	=> 'text'
	));

	//Layouts
	$wp_customize->add_section( 'home_construction_company_left_right', array(
    	'title'      => __( 'Theme Layout Settings', 'home-construction-company' ),
		'priority'   => 30,
		'panel' => 'home_construction_company_panel_id'
	) );

	$wp_customize->add_setting('home_construction_company_width_options',array(
        'default' => 'Full Layout',
        'sanitize_callback' => 'home_construction_company_sanitize_choices'
	));
	$wp_customize->add_control('home_construction_company_width_options',array(
        'type' => 'select',
        'label' => __('Select Site Layout','home-construction-company'),
        'section' => 'home_construction_company_left_right',
        'choices' => array(
            'Full Layout' => __('Full Layout','home-construction-company'),
            'Contained Layout' => __('Contained Layout','home-construction-company'),
            'Boxed Layout' => __('Boxed Layout','home-construction-company'),
        ),
	) );

	// Add Settings and Controls for Layout
	$wp_customize->add_setting('home_construction_company_theme_options',array(
        'default' => 'Right Sidebar',
        'sanitize_callback' => 'home_construction_company_sanitize_choices'
	) );
	$wp_customize->add_control('home_construction_company_theme_options', array(
        'type' => 'radio',
        'label' => __('Sidebar Layout','home-construction-company'),
        'section' => 'home_construction_company_left_right',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','home-construction-company'),
            'Right Sidebar' => __('Right Sidebar','home-construction-company'),
            'One Column' => __('One Column','home-construction-company'),
            'Three Columns' => __('Three Columns','home-construction-company'),
            'Four Columns' => __('Four Columns','home-construction-company'),
            'Grid Layout' => __('Grid Layout','home-construction-company')
        ),
    ));

	// Add Settings and Controls for Layout
	$wp_customize->add_setting('home_construction_company_single_post_sidebar',array(
        'default' => 'Right Sidebar',
        'sanitize_callback' => 'home_construction_company_sanitize_choices'
	) );
	$wp_customize->add_control('home_construction_company_single_post_sidebar', array(
        'type' => 'radio',
        'label' => __('Single Post Sidebar Layout','home-construction-company'),
        'section' => 'home_construction_company_left_right',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','home-construction-company'),
            'Right Sidebar' => __('Right Sidebar','home-construction-company'),
            'One Column' => __('One Column','home-construction-company'),
        ),
    ));

	// Preloader
	$wp_customize->add_setting( 'home_construction_company_preloader_hide',array(
		'default' => false,
      	'sanitize_callback'	=> 'home_construction_company_sanitize_checkbox'
    ) );
    $wp_customize->add_control('home_construction_company_preloader_hide',array(
    	'type' => 'checkbox',
        'label' => __( 'Show / Hide Preloader','home-construction-company' ),
        'section' => 'home_construction_company_left_right'
    ));

    $wp_customize->add_setting('home_construction_company_preloader_type',array(
        'default'   => 'center-square',
        'sanitize_callback' => 'home_construction_company_sanitize_choices'
	));
	$wp_customize->add_control( 'home_construction_company_preloader_type', array(
		'label' => __( 'Preloader Type','home-construction-company' ),
		'section' => 'home_construction_company_left_right',
		'type'  => 'select',
		'settings' => 'home_construction_company_preloader_type',
		'choices' => array(
		    'center-square' => __('Center Square','home-construction-company'),
		    'chasing-square' => __('Chasing Square','home-construction-company'),
	    ),
	));

	$wp_customize->add_setting( 'home_construction_company_preloader_color', array(
	    'default' => '#333333',
	    'sanitize_callback' => 'sanitize_hex_color'
  	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'home_construction_company_preloader_color', array(
  		'label' => 'Preloader Color',
	    'section' => 'home_construction_company_left_right',
	    'settings' => 'home_construction_company_preloader_color',
  	)));

  	$wp_customize->add_setting( 'home_construction_company_preloader_bg_color', array(
	    'default' => '#fff',
	    'sanitize_callback' => 'sanitize_hex_color'
  	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'home_construction_company_preloader_bg_color', array(
  		'label' => 'Preloader Background Color',
	    'section' => 'home_construction_company_left_right',
	    'settings' => 'home_construction_company_preloader_bg_color',
  	)));

     //topbar
	$wp_customize->add_section('home_construction_company_topbar',array(
		'title'	=> __('Social Icons','home-construction-company'),
		'priority'	=> null,
		'panel' => 'home_construction_company_panel_id',
	));

	$wp_customize->selective_refresh->add_partial(
		'home_construction_company_facebook_url',
		array(
			'selector'        => '.social-media',
			'render_callback' => 'home_construction_company_customize_partial_home_construction_company_facebook_url',
		)
	);

	$wp_customize->add_setting('home_construction_company_facebook_url',array(
		'default'	=> '',
		'sanitize_callback'	=> 'esc_url_raw'
	));
	$wp_customize->add_control('home_construction_company_facebook_url',array(
		'label'	=> __('Add Facebook link','home-construction-company'),
		'section'	=> 'home_construction_company_topbar',
		'setting'	=> 'home_construction_company_facebook_url',
		'type'	=> 'url'
	));

	$wp_customize->add_setting('home_construction_company_twitter_url',array(
		'default'	=> '',
		'sanitize_callback'	=> 'esc_url_raw'
	));
	$wp_customize->add_control('home_construction_company_twitter_url',array(
		'label'	=> __('Add Twitter link','home-construction-company'),
		'section'	=> 'home_construction_company_topbar',
		'setting'	=> 'home_construction_company_twitter_url',
		'type'	=> 'url'
	));

	$wp_customize->add_setting('home_construction_company_instagram_url',array(
		'default'	=> '',
		'sanitize_callback'	=> 'esc_url_raw'
	));	
	$wp_customize->add_control('home_construction_company_instagram_url',array(
		'label'	=> __('Add Instagram link','home-construction-company'),
		'section'	=> 'home_construction_company_topbar',
		'setting'	=> 'home_construction_company_instagram_url',
		'type'	=> 'url'
	));

	$wp_customize->add_setting('home_construction_company_linkdin_url',array(
		'default'	=> '',
		'sanitize_callback'	=> 'esc_url_raw'
	));	
	$wp_customize->add_control('home_construction_company_linkdin_url',array(
		'label'	=> __('Add Linkedin link','home-construction-company'),
		'section'	=> 'home_construction_company_topbar',
		'setting'	=> 'home_construction_company_linkdin_url',
		'type'	=> 'url'
	));

	$wp_customize->add_setting('home_construction_company_youtube_url',array(
		'default'	=> '',
		'sanitize_callback'	=> 'esc_url_raw'
	));	
	$wp_customize->add_control('home_construction_company_youtube_url',array(
		'label'	=> __('Add Youtube link','home-construction-company'),
		'section'	=> 'home_construction_company_topbar',
		'setting'	=> 'home_construction_company_youtube_url',
		'type'		=> 'url'
	));

	$wp_customize->add_setting('home_construction_company_pintrest_url',array(
		'default'	=> '',
		'sanitize_callback'	=> 'esc_url_raw'
	));	
	$wp_customize->add_control('home_construction_company_pintrest_url',array(
		'label'	=> __('Add pintrest link','home-construction-company'),
		'section'	=> 'home_construction_company_topbar',
		'setting'	=> 'home_construction_company_pintrest_url',
		'type'		=> 'url'
	));

	//Header
	$wp_customize->add_section('home_construction_company_header',array(
		'title'	=> __('Header','home-construction-company'),
		'priority'	=> null,
		'panel' => 'home_construction_company_panel_id',
	));

	//Sticky Header
	$wp_customize->add_setting( 'home_construction_company_sticky_header',array(
      	'sanitize_callback'	=> 'home_construction_company_sanitize_checkbox'
    ) );
    $wp_customize->add_control('home_construction_company_sticky_header',array(
    	'type' => 'checkbox',
        'label' => __( 'Sticky Header','home-construction-company' ),
        'section' => 'home_construction_company_header'
    ));

    $wp_customize->add_setting('home_construction_company_sticky_header_padding', array(
		'default'=> '',
		'sanitize_callback'	=> 'home_construction_company_sanitize_float'
	));
	$wp_customize->add_control('home_construction_company_sticky_header_padding', array(
		'label'	=> __('Sticky Header Padding','home-construction-company'),
		'input_attrs' => array(
            'step' => 1,
			'min'  => 0,
			'max'  => 50,
        ),
		'section'=> 'home_construction_company_header',
		'type'=> 'number',
	));

	$wp_customize->add_setting('home_construction_company_search_icon',array(
		'default'	=> 'fas fa-search',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control(new Home_Construction_Company_Icon_Changer(
        $wp_customize, 'home_construction_company_search_icon',array(
		'label'	=> __('Search Icon','home-construction-company'),
		'section'	=> 'home_construction_company_header',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting('home_construction_company_location',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));

	$wp_customize->add_control('home_construction_company_location',array(
		'label'	=> __('Location','home-construction-company'),
		'section'	=> 'home_construction_company_header',
		'type'		=> 'text'
	));

	$wp_customize->add_setting('home_construction_company_location1',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));

	$wp_customize->add_control('home_construction_company_location1',array(
		'label'	=> __('Other Location','home-construction-company'),
		'section'	=> 'home_construction_company_header',
		'type'		=> 'text'
	));

	$wp_customize->add_setting('home_construction_company_call',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));

	$wp_customize->add_control('home_construction_company_call',array(
		'label'	=> __('Phone Text','home-construction-company'),
		'section'	=> 'home_construction_company_header',
		'type'		=> 'text'
	));

	$wp_customize->add_setting('home_construction_company_call1',array(
		'default'	=> '',
		'sanitize_callback'	=> 'home_construction_company_sanitize_phone_number'
	));

	$wp_customize->add_control('home_construction_company_call1',array(
		'label'	=> __('Phone Number','home-construction-company'),
		'section'	=> 'home_construction_company_header',
		'type'		=> 'text'
	));

	$wp_customize->add_setting('home_construction_company_mail',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));

	$wp_customize->add_control('home_construction_company_mail',array(
		'label'	=> __('Email Text','home-construction-company'),
		'section'	=> 'home_construction_company_header',
		'type'		=> 'text'
	));

	$wp_customize->add_setting('home_construction_company_mail1',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_email'
	));

	$wp_customize->add_control('home_construction_company_mail1',array(
		'label'	=> __('Mail Address','home-construction-company'),
		'section'	=> 'home_construction_company_header',
		'type'		=> 'text'
	));

	$wp_customize->add_setting('home_construction_company_time',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));

	$wp_customize->add_control('home_construction_company_time',array(
		'label'	=> __('Contact Text','home-construction-company'),
		'section'	=> 'home_construction_company_header',
		'type'		=> 'text'
	));

	$wp_customize->add_setting('home_construction_company_time1',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));

	$wp_customize->add_control('home_construction_company_time1',array(
		'label'	=> __('Working Time','home-construction-company'),
		'section'	=> 'home_construction_company_header',
		'type'		=> 'text'
	));

	$wp_customize->add_setting('home_construction_company_navigation_case',array(
        'default' => 'uppercase',
        'sanitize_callback' => 'home_construction_company_sanitize_choices'
	));
	$wp_customize->add_control('home_construction_company_navigation_case',array(
        'type' => 'select',
        'label' => __('Navigation Case','home-construction-company'),
        'section' => 'home_construction_company_header',
        'choices' => array(
            'uppercase' => __('Uppercase','home-construction-company'),
            'capitalize' => __('Capitalize','home-construction-company'),
        ),
	) );

	$wp_customize->add_setting( 'home_construction_company_nav_font_size', array(
		'default'           => 15,
		'sanitize_callback' => 'home_construction_company_sanitize_float',
	) );
	$wp_customize->add_control( 'home_construction_company_nav_font_size', array(
		'label' => __( 'Navigation Font Size','home-construction-company' ),
		'section'     => 'home_construction_company_header',
		'type'        => 'number',
		'input_attrs' => array(
			'step' => 1,
			'min' => 0,
			'max' => 50,
		),
	) );

	$wp_customize->add_setting('home_construction_company_font_weight_menu_option',array(
        'default' => '600',
        'sanitize_callback' => 'home_construction_company_sanitize_choices'
    ));
    $wp_customize->add_control('home_construction_company_font_weight_menu_option',array(
        'type' => 'select',
        'label' => __('Navigation Font Weight','home-construction-company'),
        'section' => 'home_construction_company_header',
        'choices' => array(
            '100' => __('100','home-construction-company'),
            '200' => __('200','home-construction-company'),
            '300' => __('300','home-construction-company'),
            '400' => __('400','home-construction-company'),
            '500' => __('500','home-construction-company'),
            '600' => __('600','home-construction-company'),
            '700' => __('700','home-construction-company'),
            '800' => __('800','home-construction-company'),
            '900' => __('900','home-construction-company'),
        ),
	) );

	//home page slider
	$wp_customize->add_section( 'home_construction_company_slidersettings' , array(
    	'title'      => __( 'Slider Settings', 'home-construction-company' ),
		'priority'   => null,
		'panel' => 'home_construction_company_panel_id'
	) );

	$wp_customize->selective_refresh->add_partial(
		'home_construction_company_slider_hide_show',
		array(
			'selector'        => '#slider .inner_carousel h1',
			'render_callback' => 'home_construction_company_customize_partial_home_construction_company_slider_hide_show',
		)
	);

	$wp_customize->add_setting('home_construction_company_slider_hide_show',array(
       'default' => false,
       'sanitize_callback'	=> 'home_construction_company_sanitize_checkbox'
	));
	$wp_customize->add_control('home_construction_company_slider_hide_show',array(
	   'type' => 'checkbox',
	   'label' => __('Show / Hide slider','home-construction-company'),
	   'section' => 'home_construction_company_slidersettings',
	));

	for ( $count = 1; $count <= 4; $count++ ) {
		$wp_customize->add_setting( 'home_construction_company_slider_page' . $count, array(
			'default'  => '',
			'sanitize_callback' => 'home_construction_company_sanitize_dropdown_pages'
		) );
		$wp_customize->add_control( 'home_construction_company_slider_page' . $count, array(
			'label' => __( 'Select Slide Image Page', 'home-construction-company' ),
			'section' => 'home_construction_company_slidersettings',
			'type'    => 'dropdown-pages'
		) );
	}

	//Show / Hide slider Title
	$wp_customize->add_setting('home_construction_company_slider_title',array(
       'default' => 'true',
       'sanitize_callback'	=> 'home_construction_company_sanitize_checkbox'
	));
	
	$wp_customize->add_control('home_construction_company_slider_title',array(
	   'type' => 'checkbox',
	   'label' => __('Show / Hide slider Title','home-construction-company'),
	   'section' => 'home_construction_company_slidersettings',
	));

	//Show / Hide slider Content
	$wp_customize->add_setting('home_construction_company_slider_content',array(
       'default' => 'true',
       'sanitize_callback'	=> 'home_construction_company_sanitize_checkbox'
	));
	$wp_customize->add_control('home_construction_company_slider_content',array(
	   'type' => 'checkbox',
	   'label' => __('Show / Hide slider Content','home-construction-company'),
	   'section' => 'home_construction_company_slidersettings',
	));

	//Services Section
	$wp_customize->add_section('home_construction_company_choices_section',array(
		'title'	=> __('Services Section','home-construction-company'),
		'panel' => 'home_construction_company_panel_id',
	));

	$wp_customize->add_setting('home_construction_company_section_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('home_construction_company_section_text',array(
		'label'	=> esc_html__('Section Text','home-construction-company'),
		'section'=> 'home_construction_company_choices_section',
		'type'=> 'text'
	));	

	$wp_customize->add_setting('home_construction_company_section_title',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('home_construction_company_section_title',array(
		'label'	=> esc_html__('Section Title','home-construction-company'),
		'section'=> 'home_construction_company_choices_section',
		'type'=> 'text'
	));	

	$wp_customize->add_setting('home_construction_company_services_number',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('home_construction_company_services_number',array(
		'label'	=> esc_html__('No of Tabs to show','home-construction-company'),
		'section'=> 'home_construction_company_choices_section',
		'type'=> 'number'
	));	

	$category_post = get_theme_mod('home_construction_company_services_number','');
    for ( $j = 1; $j <= $category_post; $j++ ) {
		$wp_customize->add_setting('home_construction_company_services_text'.$j,array(
			'default'=> '',
			'sanitize_callback'	=> 'sanitize_text_field'
		));	
		$wp_customize->add_control('home_construction_company_services_text'.$j,array(
			'label'	=> esc_html__('Tab ','home-construction-company').$j,
			'section'=> 'home_construction_company_choices_section',
			'type'=> 'text'
		));

		$categories = get_categories();
			$cat_posts = array();
				$i = 0;
				$cat_posts[]='Select';
			foreach($categories as $category){
				if($i==0){
				$default = $category->slug;
				$i++;
			}
			$cat_posts[$category->slug] = $category->name;
		}

		$wp_customize->add_setting('home_construction_company_services_category'.$j,array(
			'default'	=> 'select',
			'sanitize_callback' => 'home_construction_company_sanitize_choices',
		));
		$wp_customize->add_control('home_construction_company_services_category'.$j,array(
			'type'    => 'select',
			'choices' => $cat_posts,
			'label' => __('Select Category to display images','home-construction-company'),
			'section' => 'home_construction_company_choices_section',
		));
	}

	$wp_customize->add_setting( 'home_construction_company_latest_post_button_text', array(
		'default'   => __('Get In Touch','home-construction-company' ),
		'sanitize_callback'	=> 'sanitize_text_field'
	) );
	$wp_customize->add_control( 'home_construction_company_latest_post_button_text', array(
		'label'    => __( 'Post Button text','home-construction-company' ),
		'section'  => 'home_construction_company_choices_section',
		'type'     => 'text',
		'settings' => 'home_construction_company_latest_post_button_text'
	) );

	$wp_customize->add_setting('home_construction_company_section_text1',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('home_construction_company_section_text1',array(
		'label'	=> esc_html__('Plan Text','home-construction-company'),
		'section'=> 'home_construction_company_choices_section',
		'type'=> 'text'
	));	

	$wp_customize->add_setting('home_construction_company_section_text2',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('home_construction_company_section_text2',array(
		'label'	=> esc_html__('Design Text','home-construction-company'),
		'section'=> 'home_construction_company_choices_section',
		'type'=> 'text'
	));	

	$wp_customize->add_setting('home_construction_company_section_text3',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('home_construction_company_section_text3',array(
		'label'	=> esc_html__('Delivery Text','home-construction-company'),
		'section'=> 'home_construction_company_choices_section',
		'type'=> 'text'
	));	

	//Blog Post
	$wp_customize->add_section('home_construction_company_blog_post',array(
		'title'	=> __('Post Settings','home-construction-company'),
		'panel' => 'home_construction_company_panel_id',
	));	

	$wp_customize->add_setting('home_construction_company_date_hide',array(
       'default' => true,
       'sanitize_callback'	=> 'home_construction_company_sanitize_checkbox'
    ));
    $wp_customize->add_control('home_construction_company_date_hide',array(
       'type' => 'checkbox',
       'label' => __('Enable / Disable Post Date','home-construction-company'),
       'section' => 'home_construction_company_blog_post'
    ));

    $wp_customize->add_setting('home_construction_company_author_hide',array(
       'default' => true,
       'sanitize_callback'	=> 'home_construction_company_sanitize_checkbox'
    ));
    $wp_customize->add_control('home_construction_company_author_hide',array(
       'type' => 'checkbox',
       'label' => __('Enable / Disable Post Author','home-construction-company'),
       'section' => 'home_construction_company_blog_post'
    ));

    $wp_customize->add_setting('home_construction_company_comment_hide',array(
       'default' => true,
       'sanitize_callback'	=> 'home_construction_company_sanitize_checkbox'
    ));
    $wp_customize->add_control('home_construction_company_comment_hide',array(
       'type' => 'checkbox',
       'label' => __('Enable / Disable Post Comments','home-construction-company'),
       'section' => 'home_construction_company_blog_post'
    ));

    $wp_customize->add_setting('home_construction_company_time_hide',array(
       'default' => false,
       'sanitize_callback'	=> 'home_construction_company_sanitize_checkbox'
    ));
    $wp_customize->add_control('home_construction_company_time_hide',array(
       'type' => 'checkbox',
       'label' => __('Enable / Disable Post Time','home-construction-company'),
       'section' => 'home_construction_company_blog_post'
    ));

    $wp_customize->add_setting('home_construction_company_feature_image_hide',array(
       'default' => true,
       'sanitize_callback'	=> 'home_construction_company_sanitize_checkbox'
    ));
    $wp_customize->add_control('home_construction_company_feature_image_hide',array(
       'type' => 'checkbox',
       'label' => __('Enable / Disable Featured Image','home-construction-company'),
       'section' => 'home_construction_company_blog_post'
    ));

    $wp_customize->add_setting( 'home_construction_company_featured_image_border_radius', array(
		'default' => 0,
		'sanitize_callback'	=> 'home_construction_company_sanitize_float'
	) );
	$wp_customize->add_control( 'home_construction_company_featured_image_border_radius', array(
		'label' => __( 'Featured image border radius','home-construction-company' ),
		'section' => 'home_construction_company_blog_post',
		'type'  => 'number',
		'input_attrs' => array(
			'step' => 1,
			'min'  => 0,
			'max'  => 50,
		),
	) );

    $wp_customize->add_setting( 'home_construction_company_featured_image_box_shadow', array(
		'default' => 0,
		'sanitize_callback'	=> 'home_construction_company_sanitize_float'
	) );
	$wp_customize->add_control( 'home_construction_company_featured_image_box_shadow', array(
		'label' => __( 'Featured image box shadow','home-construction-company' ),
		'section' => 'home_construction_company_blog_post',
		'type'  => 'number',
		'input_attrs' => array(
			'step' => 1,
			'min'  => 0,
			'max'  => 50,
		),
	) );

    $wp_customize->add_setting('home_construction_company_post_content',array(
    	'default' => 'Excerpt Content',
        'sanitize_callback' => 'home_construction_company_sanitize_choices'
	));
	$wp_customize->add_control('home_construction_company_post_content',array(
        'type' => 'radio',
        'label' => __('Post Content Type','home-construction-company'),
        'section' => 'home_construction_company_blog_post',
        'choices' => array(
            'No Content' => __('No Content','home-construction-company'),
            'Full Content' => __('Full Content','home-construction-company'),
            'Excerpt Content' => __('Excerpt Content','home-construction-company'),
        ),
	) );

    $wp_customize->add_setting( 'home_construction_company_post_excerpt_length', array(
		'default'              => 20,
		'sanitize_callback'	=> 'home_construction_company_sanitize_float'
	) );
	$wp_customize->add_control( 'home_construction_company_post_excerpt_length', array(
		'label' => esc_html__( 'Post Excerpt Length','home-construction-company' ),
		'section'  => 'home_construction_company_blog_post',
		'type'  => 'number',
		'settings' => 'home_construction_company_post_excerpt_length',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 0,
			'max'              => 50,
		),
	) );

	$wp_customize->add_setting( 'home_construction_company_button_excerpt_suffix', array(
		'default'   => __('[...]','home-construction-company' ),
		'sanitize_callback'	=> 'sanitize_text_field'
	) );
	$wp_customize->add_control( 'home_construction_company_button_excerpt_suffix', array(
		'label'       => esc_html__( 'Excerpt Suffix','home-construction-company' ),
		'section'     => 'home_construction_company_blog_post',
		'type'        => 'text',
		'settings' => 'home_construction_company_button_excerpt_suffix'
	) );

	$wp_customize->add_setting( 'home_construction_company_post_button_text', array(
		'default'   => esc_html__('Read More','home-construction-company' ),
		'sanitize_callback'	=> 'sanitize_text_field'
	) );
	$wp_customize->add_control( 'home_construction_company_post_button_text', array(
		'label' => esc_html__('Post Button Text','home-construction-company' ),
		'section'     => 'home_construction_company_blog_post',
		'type'        => 'text',
		'settings'    => 'home_construction_company_post_button_text'
	) );

	$wp_customize->add_setting('home_construction_company_top_button_padding',array(
		'default'=> '',
		'sanitize_callback'	=> 'home_construction_company_sanitize_float'
	));
	$wp_customize->add_control('home_construction_company_top_button_padding',array(
		'label'	=> __('Top Bottom Button Padding','home-construction-company'),
		'input_attrs' => array(
            'step' => 1,
			'min'  => 0,
			'max'  => 50,
        ),
		'section'=> 'home_construction_company_blog_post',
		'type'=> 'number',
	));

	$wp_customize->add_setting('home_construction_company_left_button_padding',array(
		'default'=> '',
		'sanitize_callback'	=> 'home_construction_company_sanitize_float'
	));
	$wp_customize->add_control('home_construction_company_left_button_padding',array(
		'label'	=> __('Left Right Button Padding','home-construction-company'),
		'input_attrs' => array(
            'step'             => 1,
			'min'              => 0,
			'max'              => 50,
        ),
		'section'=> 'home_construction_company_blog_post',
		'type'=> 'number',
	));

	$wp_customize->add_setting( 'home_construction_company_button_border_radius', array(
		'default'=> '0',
		'sanitize_callback'	=> 'home_construction_company_sanitize_float'
	) );
	$wp_customize->add_control('home_construction_company_button_border_radius', array(
        'label'  => __('Button Border Radius','home-construction-company'),
        'type'=> 'number',
        'section'  => 'home_construction_company_blog_post',
        'input_attrs' => array(
        	'step' => 1,
            'min' => 0,
            'max' => 50,
        ),
    ));

    $wp_customize->add_setting( 'home_construction_company_post_blocks', array(
        'default'			=> 'Without box',
        'sanitize_callback'	=> 'home_construction_company_sanitize_choices'
    ));
    $wp_customize->add_control( 'home_construction_company_post_blocks', array(
        'section' => 'home_construction_company_blog_post',
        'type' => 'select',
        'label' => __( 'Post blocks', 'home-construction-company' ),
        'choices' => array(
            'Within box'  => __( 'Within box', 'home-construction-company' ),
            'Without box' => __( 'Without box', 'home-construction-company' ),
    )));

    $wp_customize->add_setting('home_construction_company_navigation_hide',array(
       'default' => true,
       'sanitize_callback'	=> 'home_construction_company_sanitize_checkbox'
    ));
    $wp_customize->add_control('home_construction_company_navigation_hide',array(
       'type' => 'checkbox',
       'label' => __('Enable / Disable Post Navigation','home-construction-company'),
       'section' => 'home_construction_company_blog_post'
    ));

    $wp_customize->add_setting( 'home_construction_company_post_navigation_type', array(
        'default'			=> 'numbers',
        'sanitize_callback'	=> 'home_construction_company_sanitize_choices'
    ));
    $wp_customize->add_control( 'home_construction_company_post_navigation_type', array(
        'section' => 'home_construction_company_blog_post',
        'type' => 'select',
        'label' => __( 'Post Navigation Type', 'home-construction-company' ),
        'choices' => array(
            'numbers'  => __( 'Number', 'home-construction-company' ),
            'next-prev' => __( 'Next/Prev Button', 'home-construction-company' ),
    )));

    $wp_customize->add_setting( 'home_construction_company_post_navigation_position', array(
        'default'			=> 'bottom',
        'sanitize_callback'	=> 'home_construction_company_sanitize_choices'
    ));
    $wp_customize->add_control( 'home_construction_company_post_navigation_position', array(
        'section' => 'home_construction_company_blog_post',
        'type' => 'select',
        'label' => __( 'Post Navigation Position', 'home-construction-company' ),
        'choices' => array(
            'top'  => __( 'Top', 'home-construction-company' ),
            'bottom' => __( 'Bottom', 'home-construction-company' ),
            'both' => __( 'Both', 'home-construction-company' ),
    )));

    //Single Post Settings
	$wp_customize->add_section('home_construction_company_single_post',array(
		'title'	=> __('Single Post Settings','home-construction-company'),
		'panel' => 'home_construction_company_panel_id',
	));	

	$wp_customize->add_setting('home_construction_company_feature_image',array(
       'default' => true,
       'sanitize_callback'	=> 'home_construction_company_sanitize_checkbox'
    ));
    $wp_customize->add_control('home_construction_company_feature_image',array(
       'type' => 'checkbox',
       'label' => __('Enable / Disable Feature Image','home-construction-company'),
       'section' => 'home_construction_company_single_post'
    ));

    $wp_customize->add_setting( 'home_construction_company_single_post_img_border_radius', array(
		'default'=> 0,
		'sanitize_callback'	=> 'home_construction_company_sanitize_float',
	) );
	$wp_customize->add_control( 'home_construction_company_single_post_img_border_radius', array(
		'label'       => esc_html__( 'Single Post Image Border Radius','home-construction-company' ),
		'section'     => 'home_construction_company_single_post',
		'type'        => 'number',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 0,
			'max'              => 100,
		),
	) );

	$wp_customize->add_setting( 'home_construction_company_single_post_img_box_shadow',array(
		'default' => 0,
		'sanitize_callback'    => 'home_construction_company_sanitize_float',
	));
	$wp_customize->add_control('home_construction_company_single_post_img_box_shadow',array(
		'label' => esc_html__( 'Single Post Image Shadow','home-construction-company' ),
		'section' => 'home_construction_company_single_post',
		'input_attrs' => array(
			'min' => 0,
			'max' => 50,
			'step' => 1,
		),
		'type' => 'number'
	));

    $wp_customize->add_setting('home_construction_company_tags',array(
       'default' => true,
       'sanitize_callback'	=> 'home_construction_company_sanitize_checkbox'
    ));
    $wp_customize->add_control('home_construction_company_tags',array(
       'type' => 'checkbox',
       'label' => __('Enable / Disable Tags','home-construction-company'),
       'section' => 'home_construction_company_single_post'
    ));

    $wp_customize->add_setting('home_construction_company_comment',array(
       'default' => true,
       'sanitize_callback'	=> 'home_construction_company_sanitize_checkbox'
    ));
    $wp_customize->add_control('home_construction_company_comment',array(
       'type' => 'checkbox',
       'label' => __('Enable / Disable Comment','home-construction-company'),
       'section' => 'home_construction_company_single_post'
    ));

     $wp_customize->add_setting('home_construction_company_show_hide_single_post_categories',array(
		'default' => true,
		'sanitize_callback'	=> 'home_construction_company_sanitize_checkbox'
 	));
 	$wp_customize->add_control('home_construction_company_show_hide_single_post_categories',array(
		'type' => 'checkbox',
		'label' => __('Single Post Categories','home-construction-company'),
		'section' => 'home_construction_company_single_post'
	));

    $wp_customize->add_setting( 'home_construction_company_comment_width', array(
		'default' => 100,
		'sanitize_callback'	=> 'home_construction_company_sanitize_float'
	) );
	$wp_customize->add_control( 'home_construction_company_comment_width', array(
		'label' => __( 'Comment Textarea Width', 'home-construction-company'),
		'section' => 'home_construction_company_single_post',
		'type' => 'number',
		'settings' => 'home_construction_company_comment_width',
		'input_attrs' => array(
			'step' => 1,
			'min' => 0,
			'max' => 100,
		),
	) );

    $wp_customize->add_setting('home_construction_company_comment_title',array(
       'default' => __('Leave a Reply','home-construction-company'),
       'sanitize_callback'	=> 'sanitize_text_field'
    ));
    $wp_customize->add_control('home_construction_company_comment_title',array(
       'type' => 'text',
       'label' => __('Comment form Title','home-construction-company'),
       'section' => 'home_construction_company_single_post'
    ));

    $wp_customize->add_setting('home_construction_company_comment_submit_text',array(
       'default' => __('Post Comment','home-construction-company'),
       'sanitize_callback'	=> 'sanitize_text_field'
    ));
    $wp_customize->add_control('home_construction_company_comment_submit_text',array(
       'type' => 'text',
       'label' => __('Comment Button Text','home-construction-company'),
       'section' => 'home_construction_company_single_post'
    ));

    $wp_customize->add_setting('home_construction_company_nav_links',array(
       'default' => true,
       'sanitize_callback'	=> 'home_construction_company_sanitize_checkbox'
    ));
    $wp_customize->add_control('home_construction_company_nav_links',array(
       'type' => 'checkbox',
       'label' => __('Enable / Disable Nav Links','home-construction-company'),
       'section' => 'home_construction_company_single_post'
    ));

    $wp_customize->add_setting('home_construction_company_prev_text',array(
       'default' => '',
       'sanitize_callback'	=> 'sanitize_text_field'
    ));
    $wp_customize->add_control('home_construction_company_prev_text',array(
       'type' => 'text',
       'label' => __('Previous Navigation Text','home-construction-company'),
       'section' => 'home_construction_company_single_post'
    ));

    $wp_customize->add_setting('home_construction_company_next_text',array(
       'default' => '',
       'sanitize_callback'	=> 'sanitize_text_field'
    ));
    $wp_customize->add_control('home_construction_company_next_text',array(
       'type' => 'text',
       'label' => __('Next Navigation Text','home-construction-company'),
       'section' => 'home_construction_company_single_post'
    ));

    $wp_customize->add_setting('home_construction_company_related_posts',array(
       'default' => true,
       'sanitize_callback'	=> 'home_construction_company_sanitize_checkbox'
    ));
    $wp_customize->add_control('home_construction_company_related_posts',array(
       'type' => 'checkbox',
       'label' => __('Enable / Disable Related Posts','home-construction-company'),
       'section' => 'home_construction_company_single_post'
    ));

    $wp_customize->add_setting('home_construction_company_related_posts_title',array(
       'default' => '',
       'sanitize_callback'	=> 'sanitize_text_field'
    ));
    $wp_customize->add_control('home_construction_company_related_posts_title',array(
       'type' => 'text',
       'label' => __('Related Posts Title','home-construction-company'),
       'section' => 'home_construction_company_single_post'
    ));

    $wp_customize->add_setting( 'home_construction_company_related_post_count', array(
		'default' => 3,
		'sanitize_callback'	=> 'home_construction_company_sanitize_float'
	) );
	$wp_customize->add_control( 'home_construction_company_related_post_count', array(
		'label' => esc_html__( 'Related Posts Count','home-construction-company' ),
		'section' => 'home_construction_company_single_post',
		'type' => 'number',
		'settings' => 'home_construction_company_related_post_count',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 0,
			'max'              => 6,
		),
	) );

    $wp_customize->add_setting( 'home_construction_company_post_order', array(
        'default' => 'categories',
        'sanitize_callback'	=> 'home_construction_company_sanitize_choices'
    ));
    $wp_customize->add_control( 'home_construction_company_post_order', array(
        'section' => 'home_construction_company_single_post',
        'type' => 'radio',
        'label' => __( 'Related Posts Order By', 'home-construction-company' ),
        'choices' => array(
            'categories' => __('Categories', 'home-construction-company'),
            'tags' => __( 'Tags', 'home-construction-company' ),
    )));

    //404 page settings
	$wp_customize->add_section('home_construction_company_404_page',array(
		'title'	=> __('404 & No Result Page Settings','home-construction-company'),
		'priority'	=> null,
		'panel' => 'home_construction_company_panel_id',
	));

	$wp_customize->add_setting('home_construction_company_404_title',array(
       'default' => '',
       'sanitize_callback'	=> 'sanitize_text_field'
    ));
    $wp_customize->add_control('home_construction_company_404_title',array(
       'type' => 'text',
       'label' => __('404 Page Title','home-construction-company'),
       'section' => 'home_construction_company_404_page'
    ));

    $wp_customize->add_setting('home_construction_company_404_text',array(
       'default' => '',
       'sanitize_callback'	=> 'sanitize_text_field'
    ));
    $wp_customize->add_control('home_construction_company_404_text',array(
       'type' => 'text',
       'label' => __('404 Page Text','home-construction-company'),
       'section' => 'home_construction_company_404_page'
    ));

    $wp_customize->add_setting('home_construction_company_404_button_text',array(
       'default' => '',
       'sanitize_callback'	=> 'sanitize_text_field'
    ));
    $wp_customize->add_control('home_construction_company_404_button_text',array(
       'type' => 'text',
       'label' => __('404 Page Button Text','home-construction-company'),
       'section' => 'home_construction_company_404_page'
    ));

    $wp_customize->add_setting('home_construction_company_no_result_title',array(
       'default' => '',
       'sanitize_callback'	=> 'sanitize_text_field'
    ));
    $wp_customize->add_control('home_construction_company_no_result_title',array(
       'type' => 'text',
       'label' => __('No Result Page Title','home-construction-company'),
       'section' => 'home_construction_company_404_page'
    ));

    $wp_customize->add_setting('home_construction_company_no_result_text',array(
       'default' => '',
       'sanitize_callback'	=> 'sanitize_text_field'
    ));
    $wp_customize->add_control('home_construction_company_no_result_text',array(
       'type' => 'text',
       'label' => __('No Result Page Text','home-construction-company'),
       'section' => 'home_construction_company_404_page'
    ));

    $wp_customize->add_setting('home_construction_company_show_search_form',array(
        'default' => true,
        'sanitize_callback'	=> 'home_construction_company_sanitize_checkbox'
	));
	$wp_customize->add_control('home_construction_company_show_search_form',array(
     	'type' => 'checkbox',
      	'label' => __('Show/Hide Search Form','home-construction-company'),
      	'section' => 'home_construction_company_404_page',
	));

	//Footer
	$wp_customize->add_section('home_construction_company_footer_section',array(
		'title'	=> __('Footer Section','home-construction-company'),
		'priority'	=> null,
		'panel' => 'home_construction_company_panel_id',
	));

	$wp_customize->selective_refresh->add_partial(
		'home_construction_company_show_back_to_top',
		array(
			'selector'        => '.scrollup',
			'render_callback' => 'home_construction_company_customize_partial_home_construction_company_show_back_to_top',
		)
	);

	$wp_customize->add_setting('home_construction_company_show_back_to_top',array(
        'default' => 'true',
        'sanitize_callback'	=> 'home_construction_company_sanitize_checkbox'
	));
	$wp_customize->add_control('home_construction_company_show_back_to_top',array(
     	'type' => 'checkbox',
      	'label' => __('Show/Hide Back to Top Button','home-construction-company'),
      	'section' => 'home_construction_company_footer_section',
	));

	$wp_customize->add_setting('home_construction_company_back_to_top_icon',array(
		'default'	=> 'fas fa-arrow-up',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control(new Home_Construction_Company_Icon_Changer(
        $wp_customize, 'home_construction_company_back_to_top_icon',array(
		'label'	=> __('Back to Top Icon','home-construction-company'),
		'section'	=> 'home_construction_company_footer_section',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting('home_construction_company_back_to_top_text',array(
		'default'	=> __('Back to Top','home-construction-company'),
		'sanitize_callback'	=> 'sanitize_text_field',
	));	
	$wp_customize->add_control('home_construction_company_back_to_top_text',array(
		'label'	=> __('Back to Top Button Text','home-construction-company'),
		'section'	=> 'home_construction_company_footer_section',
		'type'		=> 'text'
	));

	$wp_customize->add_setting('home_construction_company_back_to_top_alignment',array(
        'default' => 'Right',
        'sanitize_callback' => 'home_construction_company_sanitize_choices'
	));
	$wp_customize->add_control('home_construction_company_back_to_top_alignment',array(
        'type' => 'select',
        'label' => __('Back to Top Button Alignment','home-construction-company'),
        'section' => 'home_construction_company_footer_section',
        'choices' => array(
            'Left' => __('Left','home-construction-company'),
            'Right' => __('Right','home-construction-company'),
            'Center' => __('Center','home-construction-company'),
        ),
	) );

	$wp_customize->add_setting('home_construction_company_footer_background_color', array(
		'default'           => '#000',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'home_construction_company_footer_background_color', array(
		'label'    => __('Footer Background Color', 'home-construction-company'),
		'section'  => 'home_construction_company_footer_section',
	)));

	$wp_customize->add_setting('home_construction_company_footer_background_img',array(
		'default'	=> '',
		'sanitize_callback'	=> 'esc_url_raw',
	));
	$wp_customize->add_control( new WP_Customize_Image_Control($wp_customize,'home_construction_company_footer_background_img',array(
        'label' => __('Footer Background Image','home-construction-company'),
        'section' => 'home_construction_company_footer_section'
	)));

	$wp_customize->add_setting('home_construction_company_footer_widget_layout',array(
        'default'           => '4',
        'sanitize_callback' => 'home_construction_company_sanitize_choices',
    ));
    $wp_customize->add_control('home_construction_company_footer_widget_layout',array(
        'type' => 'radio',
        'label'  => __('Footer widget layout', 'home-construction-company'),
        'section'     => 'home_construction_company_footer_section',
        'description' => __('Select the number of widget areas you want in the footer. After that, go to Appearance > Widgets and add your widgets.', 'home-construction-company'),
        'choices' => array(
            '1'     => __('One', 'home-construction-company'),
            '2'     => __('Two', 'home-construction-company'),
            '3'     => __('Three', 'home-construction-company'),
            '4'     => __('Four', 'home-construction-company')
        ),
    ));

    $wp_customize->add_setting('home_construction_company_copyright_alignment',array(
        'default' => 'Center',
        'sanitize_callback' => 'home_construction_company_sanitize_choices'
	));
	$wp_customize->add_control('home_construction_company_copyright_alignment',array(
        'type' => 'select',
        'label' => __('Copyright Alignment','home-construction-company'),
        'section' => 'home_construction_company_footer_section',
        'choices' => array(
            'Left' => __('Left','home-construction-company'),
            'Right' => __('Right','home-construction-company'),
            'Center' => __('Center','home-construction-company'),
        ),
	) );

	$wp_customize->add_setting('home_construction_company_copyright_fontsize',array(
		'default'	=> 16,
		'sanitize_callback'	=> 'home_construction_company_sanitize_float',
	));	
	$wp_customize->add_control('home_construction_company_copyright_fontsize',array(
		'label'	=> __('Copyright Font Size','home-construction-company'),
		'section'	=> 'home_construction_company_footer_section',
		'type'		=> 'number'
	));

	$wp_customize->add_setting('home_construction_company_copyright_top_bottom_padding',array(
		'default'	=> 15,
		'sanitize_callback'	=> 'home_construction_company_sanitize_float',
	));	
	$wp_customize->add_control('home_construction_company_copyright_top_bottom_padding',array(
		'label'	=> __('Copyright Top Bottom Padding','home-construction-company'),
		'section'	=> 'home_construction_company_footer_section',
		'type'		=> 'number'
	));

    $wp_customize->selective_refresh->add_partial(
		'home_construction_company_footer_copy',
		array(
			'selector'        => '#footer p',
			'render_callback' => 'home_construction_company_customize_partial_home_construction_company_footer_copy',
		)
	);
	
	$wp_customize->add_setting('home_construction_company_footer_copy',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field',
	));	
	$wp_customize->add_control('home_construction_company_footer_copy',array(
		'label'	=> __('Copyright Text','home-construction-company'),
		'section'	=> 'home_construction_company_footer_section',
		'type'		=> 'text'
	));

	//Mobile Media Section
	$wp_customize->add_section( 'home_construction_company_mobile_media_options' , array(
    	'title'      => __( 'Mobile Media Options', 'home-construction-company' ),
		'priority'   => null,
		'panel' => 'home_construction_company_panel_id'
	) );

	$wp_customize->add_setting('home_construction_company_responsive_open_menu_icon',array(
		'default'	=> 'fas fa-bars',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control(new Home_Construction_Company_Icon_Changer(
        $wp_customize, 'home_construction_company_responsive_open_menu_icon',array(
		'label'	=> __('Open Menu Icon','home-construction-company'),
		'section'	=> 'home_construction_company_mobile_media_options',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting('home_construction_company_responsive_close_menu_icon',array(
		'default'	=> 'fas fa-times',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control(new Home_Construction_Company_Icon_Changer(
        $wp_customize, 'home_construction_company_responsive_close_menu_icon',array(
		'label'	=> __('Close Menu Icon','home-construction-company'),
		'section'	=> 'home_construction_company_mobile_media_options',
		'type'		=> 'icon'
	)));

    $wp_customize->add_setting('home_construction_company_responsive_show_back_to_top',array(
        'default' => true,
        'sanitize_callback'	=> 'home_construction_company_sanitize_checkbox'
	));
	$wp_customize->add_control('home_construction_company_responsive_show_back_to_top',array(
     	'type' => 'checkbox',
      	'label' => __('Show / Hide Back to Top Button','home-construction-company'),
      	'section' => 'home_construction_company_mobile_media_options',
	));

	$wp_customize->add_setting( 'home_construction_company_responsive_preloader_hide',array(
		'default' => false,
      	'sanitize_callback'	=> 'home_construction_company_sanitize_checkbox'
    ) );
    $wp_customize->add_control('home_construction_company_responsive_preloader_hide',array(
    	'type' => 'checkbox',
        'label' => __( 'Show / Hide Preloader','home-construction-company' ),
        'section' => 'home_construction_company_mobile_media_options'
    ));

	//Woocommerce Section
	$wp_customize->add_section( 'home_construction_company_woocommerce_options' , array(
    	'title'      => __( 'Additional WooCommerce Options', 'home-construction-company' ),
		'priority'   => null,
		'panel' => 'home_construction_company_panel_id'
	) );

	// Product Columns
	$wp_customize->add_setting( 'home_construction_company_products_per_row' , array(
		'default'           => '3',
		'sanitize_callback' => 'home_construction_company_sanitize_choices',
	) );

	$wp_customize->add_control('home_construction_company_products_per_row', array(
		'label' => __( 'Product per row', 'home-construction-company' ),
		'section'  => 'home_construction_company_woocommerce_options',
		'type'     => 'select',
		'choices'  => array(
			'2' => '2',
			'3' => '3',
			'4' => '4',
		),
	) );

	$wp_customize->add_setting('home_construction_company_product_per_page',array(
		'default'	=> '9',
		'sanitize_callback'	=> 'home_construction_company_sanitize_float'
	));	
	$wp_customize->add_control('home_construction_company_product_per_page',array(
		'label'	=> __('Product per page','home-construction-company'),
		'section'	=> 'home_construction_company_woocommerce_options',
		'type'		=> 'number'
	));

	$wp_customize->add_setting('home_construction_company_shop_sidebar',array(
       'default' => true,
       'sanitize_callback'	=> 'home_construction_company_sanitize_checkbox'
    ));
    $wp_customize->add_control('home_construction_company_shop_sidebar',array(
       'type' => 'checkbox',
       'label' => __('Enable / Disable Shop page sidebar','home-construction-company'),
       'section' => 'home_construction_company_woocommerce_options',
    ));

    // shop page sidebar alignment
    $wp_customize->add_setting('home_construction_company_shop_page_layout', array(
		'default'           => 'Right Sidebar',
		'sanitize_callback' => 'home_construction_company_sanitize_choices',
	));
	$wp_customize->add_control('home_construction_company_shop_page_layout',array(
		'type'           => 'radio',
		'label'          => __('Shop Page layout', 'home-construction-company'),
		'section'        => 'home_construction_company_woocommerce_options',
		'choices'        => array(
			'Left Sidebar'  => __('Left Sidebar', 'home-construction-company'),
			'Right Sidebar' => __('Right Sidebar', 'home-construction-company'),
		),
	));

	// single product page sidebar
	$wp_customize->add_setting( 'home_construction_company_wocommerce_single_page_sidebar',array(
		'default' => true,
		'sanitize_callback'	=> 'home_construction_company_sanitize_checkbox'
    ) );
    $wp_customize->add_control('home_construction_company_wocommerce_single_page_sidebar',array(
    	'type' => 'checkbox',
       	'label' => __('Enable / Disable Single Product Page Sidebar','home-construction-company'),
		'section' => 'home_construction_company_woocommerce_options'
    ));

    // single product page sidebar alignment
    $wp_customize->add_setting('home_construction_company_single_product_page_layout', array(
		'default'           => 'Right Sidebar',
		'sanitize_callback' => 'home_construction_company_sanitize_choices',
	));
	$wp_customize->add_control('home_construction_company_single_product_page_layout',array(
		'type'           => 'radio',
		'label'          => __('Single product Page layout', 'home-construction-company'),
		'section'        => 'home_construction_company_woocommerce_options',
		'choices'        => array(
			'Left Sidebar'  => __('Left Sidebar', 'home-construction-company'),
			'Right Sidebar' => __('Right Sidebar', 'home-construction-company'),
		),
	));

	$wp_customize->add_setting('home_construction_company_shop_page_pagination',array(
       'default' => true,
       'sanitize_callback'	=> 'home_construction_company_sanitize_checkbox'
    ));
    $wp_customize->add_control('home_construction_company_shop_page_pagination',array(
       'type' => 'checkbox',
       'label' => __('Enable / Disable Shop page pagination','home-construction-company'),
       'section' => 'home_construction_company_woocommerce_options',
    ));

    $wp_customize->add_setting('home_construction_company_product_page_sidebar',array(
       'default' => true,
       'sanitize_callback'	=> 'home_construction_company_sanitize_checkbox'
    ));
    $wp_customize->add_control('home_construction_company_product_page_sidebar',array(
       'type' => 'checkbox',
       'label' => __('Enable / Disable Product page sidebar','home-construction-company'),
       'section' => 'home_construction_company_woocommerce_options',
    ));

    $wp_customize->add_setting('home_construction_company_related_product',array(
       'default' => true,
       'sanitize_callback'	=> 'home_construction_company_sanitize_checkbox'
    ));
    $wp_customize->add_control('home_construction_company_related_product',array(
       'type' => 'checkbox',
       'label' => __('Enable / Disable Related product','home-construction-company'),
       'section' => 'home_construction_company_woocommerce_options',
    ));

	$wp_customize->add_setting( 'home_construction_company_woocommerce_button_padding_top',array(
		'default' => 10,
		'sanitize_callback' => 'home_construction_company_sanitize_float'
	));
	$wp_customize->add_control( 'home_construction_company_woocommerce_button_padding_top',	array(
		'label' => esc_html__( 'Button Top Bottom Padding','home-construction-company' ),
		'type' => 'number',
		'section' => 'home_construction_company_woocommerce_options',
		'input_attrs' => array(
			'min' => 0,
			'max' => 50,
			'step' => 1,
		),
	));

	$wp_customize->add_setting( 'home_construction_company_woocommerce_button_padding_right',array(
	 	'default' => 20,
	 	'sanitize_callback' => 'home_construction_company_sanitize_float'
	));
	$wp_customize->add_control('home_construction_company_woocommerce_button_padding_right',	array(
	 	'label' => esc_html__( 'Button Right Left Padding','home-construction-company' ),
		'type' => 'number',
		'section' => 'home_construction_company_woocommerce_options',
	 	'input_attrs' => array(
			'min' => 0,
			'max' => 50,
	 		'step' => 1,
		),
	));

	$wp_customize->add_setting( 'home_construction_company_woocommerce_button_border_radius',array(
		'default' => 0,
		'sanitize_callback' => 'home_construction_company_sanitize_float'
	));
	$wp_customize->add_control('home_construction_company_woocommerce_button_border_radius',array(
		'label' => esc_html__( 'Button Border Radius','home-construction-company' ),
		'type' => 'number',
		'section' => 'home_construction_company_woocommerce_options',
		'input_attrs' => array(
			'min' => 0,
			'max' => 50,
			'step' => 1,
		),
	));

    $wp_customize->add_setting('home_construction_company_woocommerce_product_border',array(
       'default' => false,
       'sanitize_callback'	=> 'home_construction_company_sanitize_checkbox'
    ));
    $wp_customize->add_control('home_construction_company_woocommerce_product_border',array(
       'type' => 'checkbox',
       'label' => __('Enable / Disable product border','home-construction-company'),
       'section' => 'home_construction_company_woocommerce_options',
    ));

	$wp_customize->add_setting( 'home_construction_company_woocommerce_product_padding_top',array(
		'default' => 0,
		'sanitize_callback' => 'home_construction_company_sanitize_float'
	));
	$wp_customize->add_control('home_construction_company_woocommerce_product_padding_top', array(
		'label' => esc_html__( 'Product Top Bottom Padding','home-construction-company' ),
		'type' => 'number',
		'section' => 'home_construction_company_woocommerce_options',
		'input_attrs' => array(
			'min' => 0,
			'max' => 50,
			'step' => 1,
		),
	));

	$wp_customize->add_setting( 'home_construction_company_woocommerce_product_padding_right',array(
		'default' => 0,
		'sanitize_callback' => 'home_construction_company_sanitize_float'
	));
	$wp_customize->add_control('home_construction_company_woocommerce_product_padding_right', array(
		'label' => esc_html__( 'Product Right Left Padding','home-construction-company' ),
		'type' => 'number',
		'section' => 'home_construction_company_woocommerce_options',
		'input_attrs' => array(
			'min' => 0,
			'max' => 50,
			'step' => 1,
		),
	));

	$wp_customize->add_setting( 'home_construction_company_woocommerce_product_border_radius',array(
		'default' => 0,
		'sanitize_callback' => 'home_construction_company_sanitize_float'
	));
	$wp_customize->add_control('home_construction_company_woocommerce_product_border_radius',array(
		'label' => esc_html__( 'Product Border Radius','home-construction-company' ),
		'type' => 'number',
		'section' => 'home_construction_company_woocommerce_options',
		'input_attrs' => array(
			'min' => 0,
			'max' => 50,
			'step' => 1,
		),
	));

	$wp_customize->add_setting( 'home_construction_company_woocommerce_product_box_shadow',array(
		'default' => 0,
		'sanitize_callback' => 'home_construction_company_sanitize_float'
	));
	$wp_customize->add_control( 'home_construction_company_woocommerce_product_box_shadow',array(
		'label' => esc_html__( 'Product Box Shadow','home-construction-company' ),
		'type' => 'number',
		'section' => 'home_construction_company_woocommerce_options',
		'input_attrs' => array(
			'min' => 0,
			'max' => 50,
			'step' => 1,
		),
	));

	$wp_customize->add_setting('home_construction_company_sale_position',array(
        'default' => 'left',
        'sanitize_callback' => 'home_construction_company_sanitize_choices'
	));
	$wp_customize->add_control('home_construction_company_sale_position',array(
        'type' => 'select',
        'label' => __('Sale badge Position','home-construction-company'),
        'section' => 'home_construction_company_woocommerce_options',
        'choices' => array(
            'left' => __('Left','home-construction-company'),
            'right' => __('Right','home-construction-company'),
        ),
	) );

	$wp_customize->add_setting( 'home_construction_company_woocommerce_sale_top_padding',array(
		'default' => 5,
		'sanitize_callback' => 'home_construction_company_sanitize_float'
	));
	$wp_customize->add_control( 'home_construction_company_woocommerce_sale_top_padding',	array(
		'label' => esc_html__( 'Sale Top Bottom Padding','home-construction-company' ),
		'type' => 'number',
		'section' => 'home_construction_company_woocommerce_options',
		'input_attrs' => array(
			'min' => 0,
			'max' => 50,
			'step' => 1,
		),
	));

	$wp_customize->add_setting( 'home_construction_company_woocommerce_sale_left_padding',array(
	 	'default' => 0,
	 	'sanitize_callback' => 'home_construction_company_sanitize_float'
	));
	$wp_customize->add_control('home_construction_company_woocommerce_sale_left_padding',	array(
	 	'label' => esc_html__( 'Sale Right Left Padding','home-construction-company' ),
		'type' => 'number',
		'section' => 'home_construction_company_woocommerce_options',
	 	'input_attrs' => array(
			'min' => 0,
			'max' => 50,
	 		'step' => 1,
		),
	));

	$wp_customize->add_setting( 'home_construction_company_woocommerce_sale_border_radius',array(
		'default' => 0,
		'sanitize_callback' => 'home_construction_company_sanitize_float'
	));
	$wp_customize->add_control('home_construction_company_woocommerce_sale_border_radius',array(
		'label' => esc_html__( 'Sale Border Radius','home-construction-company' ),
		'type' => 'number',
		'section' => 'home_construction_company_woocommerce_options',
		'input_attrs' => array(
			'min' => 0,
			'max' => 50,
			'step' => 1,
		),
	));

	$wp_customize->add_setting( 'home_construction_company_product_sale_font_size',array(
		'default' => '',
		'sanitize_callback' => 'home_construction_company_sanitize_float'
	));
	$wp_customize->add_control('home_construction_company_product_sale_font_size',array(
		'label' => esc_html__( 'Sale Font Size','home-construction-company' ),
		'type' => 'number',
		'section' => 'home_construction_company_woocommerce_options',
		'input_attrs' => array(
			'min' => 0,
			'max' => 50,
			'step' => 1,
		),
	));
}
add_action( 'customize_register', 'home_construction_company_customize_register' );

// logo resize
load_template( trailingslashit( get_template_directory() ) . '/inc/logo/logo-width.php' );


/**
 * Singleton class for handling the theme's customizer integration.
 *
 * @since  1.0.0
 * @access public
 */
final class Home_Construction_Company_Customize {

	/**
	 * Returns the instance.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return object
	 */
	public static function get_instance() {

		static $instance = null;

		if ( is_null( $instance ) ) {
			$instance = new self;
			$instance->setup_actions();
		}

		return $instance;
	}

	/**
	 * Constructor method.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function __construct() {}

	/**
	 * Sets up initial actions.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function setup_actions() {

		// Register panels, sections, settings, controls, and partials.
		add_action( 'customize_register', array( $this, 'sections' ) );

		// Register scripts and styles for the controls.
		add_action( 'customize_controls_enqueue_scripts', array( $this, 'enqueue_control_scripts' ), 0 );
	}

	/**
	 * Sets up the customizer sections.
	 *
	 * @since  1.0.0
	 * @access public
	 * @param  object  $manager
	 * @return void
	 */
	public function sections( $manager ) {

		// Load custom sections.
		load_template( trailingslashit( get_template_directory() ) . '/inc/section-pro.php' );
		
		// Register custom section types.
		$manager->register_section_type( 'Home_Construction_Company_Customize_Section_Pro' );

		// Register sections.
		$manager->add_section(
			new Home_Construction_Company_Customize_Section_Pro(
				$manager,
				'home_construction_company_example_1',
				array(
					'priority' => 9,
					'title'    => esc_html__( 'Home Construction Pro', 'home-construction-company' ),
					'pro_text' => esc_html__( 'Go Pro','home-construction-company' ),
					'pro_url'  => esc_url( 'https://www.themescaliber.com/themes/construction-company-wordpress-theme/' ),
				)
			)
		);
	}

	/**
	 * Loads theme customizer CSS.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return void
	 */
	public function enqueue_control_scripts() {

		wp_enqueue_script( 'home-construction-company-customize-controls', trailingslashit( esc_url(get_template_directory_uri()) ) . '/js/customize-controls.js', array( 'customize-controls' ) );

		wp_enqueue_style( 'home-construction-company-customize-controls', trailingslashit( esc_url(get_template_directory_uri()) ) . '/css/customize-controls.css' );
	}
}

// Doing this customizer thang!
Home_Construction_Company_Customize::get_instance();